
local accel, friction = 1800, 0.03
local maxLength = 30

local function update(dragon, ax, ay, dt)
	local x, y = unpack(dragon[#dragon])
	local r = dragon.r
	local vx, vy = unpack(dragon.v)
	vx = vx  +  ax * accel * dt  -  friction * vx
	vy = vy  +  ay * accel * dt  -  friction * vy
	if math.abs(vx) < 0.1 then vx = 0 end
	if math.abs(vy) < 0.1 then vy = 0 end
	x = x + vx * dt
	y = y + vy * dt
	if x < r then x, vx = r, -vx
	elseif x > w - r then x, vx = w - r, -vx end
	if y < r then y, vy = r, -vy
	elseif y > h - r then y, vy = h - r, -vy end
	dragon.v[1], dragon.v[2] = vx, vy
	table.insert(dragon, {x, y})
	if #dragon > maxLength then table.remove(dragon, 1) end
end

local function draw(dragon)
	for i=1,#dragon do
		local x, y = unpack(dragon[i])
		local r = dragon.r - (#dragon - i)*dragon.dr
		love.graphics.circle('fill', x, y, r)
	end
end

local methods = { update = update, draw = draw }
local class = { __index = methods }

local function new(x, y, r)
	local d = { {x, y}, v = {0, 0}, r = r, dr = r / maxLength }
	return setmetatable(d, class)
end

return { new = new, methods = methods, class = class }
