local dragon = require('dragon')
local fly = require('fly')

function generateSeedFromClock()
	local seed = os.time() + math.floor(1000 * os.clock())
	seed = seed * seed % 1000000
	seed = seed * seed % 1000000
	return seed
end

function love.load()
	math.randomseed(generateSeedFromClock())
	w, h = love.graphics.getDimensions()
	flies = { fly.new(), fly.new(), fly.new() }
	mama = dragon.new(w/2, h/2, 30)
end

function love.keypressed(key)
	if key == 'escape' then love.event.quit() end
end

function toNum(flag) return flag and 1 or 0 end

function arrows()
	local  left = toNum(love.keyboard.isDown('left'))
	local right = toNum(love.keyboard.isDown('right'))
	local    up = toNum(love.keyboard.isDown('up'))
	local  down = toNum(love.keyboard.isDown('down'))
	return right - left, down - up
end

function collides(d, f)
	local dx, dy = unpack(d[#d])
	local d0 = (dx-f.x0)^2 + (dy-f.y0)^2
	local d1 = (dx-f.x1)^2 + (dy-f.y1)^2
	local r = (d.r + f.r)^2
	return d0 < r or d1 < r
end

function love.update(dt)
	local ax, ay = arrows()
	mama:update(ax, ay, dt)
	for i=#flies,1,-1 do
		flies[i]:update(dt)
		if collides(mama, flies[i]) then flies[i] = fly.new() end
	end
end

function love.draw()
	love.graphics.setColor(150, 150, 150)
	for i=1,#flies do flies[i]:draw() end
	love.graphics.setColor(200, 45, 30)
	mama:draw()
end
